<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="2.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:k4="http://www.vjoon.com/K4Export/2.1">

	<xsl:output method="xml" version="1.0" encoding="UTF-8" indent="no"/>
	<xsl:strip-space elements="*"/>
	<xsl:template match="/">
		<root>
			<xsl:apply-templates select="//k4:article" mode="article"/>
		</root>
	</xsl:template>

	<xsl:template match="k4:article" mode="article">
		<Article>
			<xsl:attribute name="title">
				<xsl:value-of select="lower-case(k4:name)"/>
			</xsl:attribute>
			<!-- Place the article name -->
			<Title>
				<xsl:value-of select="lower-case(k4:name)"/>
			</Title>
			<!-- Process metadata -->
			<xsl:apply-templates mode="section" select="k4:section"/>
			<xsl:apply-templates mode="metadata" select="k4:metaData"/>
			<!-- Process the text objects of each article -->
			<xsl:apply-templates mode="object" select="k4:textObject"/>
		</Article>
	</xsl:template>

	<xsl:template match="k4:section" mode="section">
		<xsl:apply-templates select="k4:name" mode="name" />
	</xsl:template>

	<xsl:template match="k4:name" mode="name">
		<Section><xsl:apply-templates mode="name" /></Section>
	</xsl:template>

	<xsl:template match="k4:metaData" mode="metadata">
		<metadata>
			<xsl:attribute name="name">
				<xsl:value-of select="k4:name"/>
			</xsl:attribute>
			<xsl:apply-templates mode="string"
				select="k4:metaDataValue"/>
		</metadata>
	</xsl:template>

	<xsl:template match="k4:string" mode="string">
		<xsl:apply-templates mode="string"/>
	</xsl:template>

	<xsl:template match="k4:textObject" mode="object">
		<Content cType="Main">
			<xsl:apply-templates mode="text" select="k4:text"/>
		</Content>
	</xsl:template>

	<xsl:template match="k4:text" mode="text">
		<xsl:apply-templates mode="inlineTag1"/>
	</xsl:template>

	<xsl:template match="k4:inlineTag" mode="inlineTag1">
		<xsl:apply-templates mode="inlineTag2"/>
	</xsl:template>


	<!-- Kill all Notes -->
	<xsl:template match="k4:note" mode="inlineTag2"> </xsl:template>

	<!-- Replace all inline tags with tags based on class atttribute -->
	<xsl:template match="k4:inlineTag" mode="inlineTag2">
		<xsl:choose>
			<xsl:when test="@name = 'Bold'">
				<strong>
					<xsl:apply-templates mode="inlineTag2"/>
				</strong>
			</xsl:when>
			<xsl:when test="@name = 'Italic'">
				<em>
					<xsl:apply-templates mode="inlineTag2"/>
				</em>
			</xsl:when>
			<xsl:when test="@name = 'Italics'">
				<em>
					<xsl:apply-templates mode="inlineTag2"/>
				</em>
			</xsl:when>
			<xsl:when test="@name = 'BoldItalic'">
				<strong>
					<em>
						<xsl:apply-templates mode="inlineTag2"/>
					</em>
				</strong>
			</xsl:when>
			<xsl:when test="@name = 'Caption'">
				<Picture>
					<Caption>
						<xsl:apply-templates mode="inlineTag2"/>
					</Caption>
				</Picture>
			</xsl:when>
			<xsl:otherwise>
				<xsl:element name="{@name}">
					<xsl:apply-templates mode="inlineTag2"/>
				</xsl:element>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<!-- Work on tables -->
	<xsl:template match="k4:table" mode="inlineTag2">
		<Table>
			<xsl:apply-templates mode="tables"/>
		</Table>
	</xsl:template>

	<xsl:template match="k4:tr" mode="tables">
		<Table-Row>
			<xsl:apply-templates mode="tables"/>
		</Table-Row>
	</xsl:template>

	<xsl:template match="k4:td" mode="tables">
		<TD>
			<xsl:apply-templates/>
		</TD>
	</xsl:template>
</xsl:stylesheet>
